==> haskell-dependent-sum-0.7.1.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum
version:              0.7.1.0
visibility:           public
id:                   dependent-sum-0.7.1.0-H7eeZsXazPd9ywezSU1esf
key:                  dependent-sum-0.7.1.0-H7eeZsXazPd9ywezSU1esf
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  7eefcf8755c6c10e0b0e3aa2efa7a23b
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.GADT.Show,
    Data.Some from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.Some

import-dirs:          /usr/lib/ghc-9.0.1/site-local/dependent-sum-0.7.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/dependent-sum-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/dependent-sum-0.7.1.0
hs-libraries:         HSdependent-sum-0.7.1.0-H7eeZsXazPd9ywezSU1esf
depends:
    base-4.15.0.0 constraints-extras-0.3.1.0-5QOXLjwQKajERmZktvIcKl
    some-1.0.3-7sghqqTkEQg7XqQ206Tg1F

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dependent-sum-0.7.1.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dependent-sum.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dependent-sum
version:              0.7.1.0
visibility:           public
id:                   dependent-sum-0.7.1.0-2PnFvDdBU5GWWF3MwW7I
key:                  dependent-sum-0.7.1.0-2PnFvDdBU5GWWF3MwW7I
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  87ad8d8f914b7022df5197f68c785bb1
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.GADT.Show,
    Data.Some from some-1.0.3-7sghqqTkEQg7XqQ206Tg1F:Data.Some

import-dirs:          /usr/lib/ghc-9.0.1/site-local/dependent-sum-0.7.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/dependent-sum-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/dependent-sum-0.7.1.0
hs-libraries:         HSdependent-sum-0.7.1.0-2PnFvDdBU5GWWF3MwW7I
depends:
    base-4.15.0.0 constraints-extras-0.3.1.0-FOb2MmXwBcR7pxQvBedrTN
    some-1.0.3-7sghqqTkEQg7XqQ206Tg1F

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
